@@ -71,6 +71,7 @@ class BackTestEngine:
     preload: bool
     account_lock: RLock
     account_info: dict
+    checkpoint: float
 
     def __init__(
         self,
@@ -87,6 +88,7 @@ class BackTestEngine:
         preload=True,
         assign_to_config: bool = True,
         account_info: dict = None,
+        checkpoint: float = 0.02
     ):
         self._data = data or BackTestData()
         self.mt5 = MetaTrader()
@@ -115,6 +117,7 @@ class BackTestEngine:
         self.preloaded_ticks = {}
         self.account_lock = RLock()
         self.account_info = account_info or {}
+        self.checkpoint = checkpoint
 
     def __next__(self) -> Cursor:
         try:
@@ -252,6 +255,8 @@ class BackTestEngine:
             profit = sum(pos.profit for pos in self.positions.open_positions)
             self.update_account(profit=profit)
             self.check_account()
+            if int(self.cursor.index % (self.range.stop * self.checkpoint)) == 0:
+                await asyncio.to_thread(self.save_result_to_json)
         except Exception as exe:
             logger.critical("Error in tracker: %s at %d", exe, self.cursor.time)
 
@@ -451,7 +456,7 @@ class BackTestEngine:
         self.positions.update(ticket=pos.ticket, **kwargs)
         await self.check_order(ticket=ticket)
 
-    @error_handler_sync
+    @error_handler
     async def close_position_manually(self, *, ticket: int):
         """Close a position manually without. Usually at the end of testing."""
         res = await self.close_position(ticket=ticket)
@@ -527,7 +532,7 @@ class BackTestEngine:
             logger.error("Error Closing Position %d: %s", ticket, exe)
             return False
 
-    @error_handler(response=False)
+    @error_handler_sync(response=False)
     def modify_stops(self, *, ticket: int, sl: int, tp: int) -> bool:
         """
         Modify the stop loss and take profit levels of an open position.
@@ -1062,6 +1067,54 @@ class BackTestEngine:
         tick = await self.get_price_tick(symbol=symbol, time=self.cursor.time)
         return tick
 
+    async def symbol_select(self, *, symbol: str, enable: bool) -> bool:
+        if self.use_terminal:
+            info = await self.mt5.symbol_select(symbol, enable)
+            return info
+        else:
+            return symbol in self._data.symbols.keys()
+
+    def symbol_select_sync(self, *, symbol: str, enable: bool = True) -> bool:
+        if self.use_terminal:
+            info = self.mt5._symbol_select(symbol, enable)
+            return info
+        else:
+            return symbol in self._data.symbols.keys()
+
+    def symbol_info_tick_sync(self, *, symbol) -> Tick | None:
+        if self.use_terminal:
+            time = datetime.fromtimestamp(self.cursor.time, tz=UTC)
+            tick = self.mt5._copy_ticks_from(symbol, time, 1, CopyTicks.ALL)
+            tick = Tick(tick[-1]) if tick is not None else None
+        else:
+            tick = self.prices[symbol].loc[self.cursor.time]
+            tick = Tick(tick) if tick is not None else None
+        return tick
+
+    def symbol_info_sync(self, *, symbol) -> SymbolInfo | None:
+        if self.use_terminal:
+            info = self.mt5._symbol_info(symbol)
+            time = datetime.fromtimestamp(self.cursor.time, tz=UTC)
+            tick = self.mt5._copy_ticks_from(symbol, time, 1, CopyTicks.ALL)
+            tick = Tick(tick[-1]) if tick is not None else None
+        else:
+            info = self.symbols[symbol]
+            tick = self.prices[symbol].loc[self.cursor.time]
+            tick = Tick(tick) if tick is not None else None
+
+        if info and tick:
+            info = info._asdict() | {
+            "bid": tick.bid,
+            "bidhigh": tick.bid,
+            "bidlow": tick.bid,
+            "ask": tick.ask,
+            "askhigh": tick.ask,
+            "asklow": tick.bid,
+            "last": tick.last,
+            "volume_real": tick.volume_real,
+            }
+            return SymbolInfo((info.get(key) for key in SymbolInfo.__match_args__))
+
     @async_cache
     async def _symbol_info(self, *, symbol: str) -> SymbolInfo:
         if self.use_terminal:
